summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-01-10 11:22:58 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-01-10 11:57:15 -0600
commitc8ada608b966ead4e76db1cac1c33a9e914f4208 (patch)
tree7c2ff4e315a786c70252f24a767b491b382dc4d9 /png.h
parent101a87cb0f2930e4062b7f825baff4ed57a847e6 (diff)
downloadlibpng-c8ada608b966ead4e76db1cac1c33a9e914f4208.tar.gz
[libpng15] Bump version to 1.5.18beta05
Diffstat (limited to 'png.h')
-rw-r--r--png.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/png.h b/png.h
index 3f13acc49..27af26dde 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.18beta04 - January 10, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.18beta04 - January 10, 2014: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -193,7 +193,7 @@
* 1.5.17beta01 15 10517 15.so.15.17[.0]
* 1.5.17rc01-03 15 10517 15.so.15.17[.0]
* 1.5.17 15 10517 15.so.15.17[.0]
- * 1.5.18beta01-04 15 10518 15.so.15.18[.0]
+ * 1.5.18beta01-05 15 10518 15.so.15.18[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -225,7 +225,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.18beta04, January 10, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -343,7 +343,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.18beta04 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -402,9 +402,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.18beta04"
+#define PNG_LIBPNG_VER_STRING "1.5.18beta05"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.18beta04 - January 10, 2014\n"
+ " libpng version 1.5.18beta05 - January 10, 2014\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -418,7 +418,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 04
+#define PNG_LIBPNG_VER_BUILD 05
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -565,7 +565,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_18beta04;
+typedef char* png_libpng_version_1_5_18beta05;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.18beta04 - January 10, 2014
+ * libpng version 1.5.18beta05 - January 10, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.18beta04 - January 10, 2014: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.18beta05 - January 10, 2014: Glenn
* See also "Contributing Authors", below.
*
@@ -225,7 +225,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.18beta04, January 10, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.18beta05, January 10, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -343,7 +343,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.18beta04 are Y2K compliant. It is my belief that
+ * upward through 1.5.18beta05 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*